package net.h34t.app.net.h34t.filemure

import io.javalin.Javalin
import io.javalin.http.staticfiles.Location
import net.h34t.filemure.FilemureApp
import net.h34t.filemure.repository.SqliteRepository
import org.eclipse.jetty.http.HttpCookie
import org.eclipse.jetty.server.session.DefaultSessionCache
import org.eclipse.jetty.server.session.FileSessionDataStore
import org.eclipse.jetty.server.session.SessionHandler
import java.io.File


fun main() {
    val db = System.getenv("dbpath")
        ?: throw IllegalArgumentException("Please define an env dbpath, e.g. /data/filemure.db")

    val app = FilemureApp(SqliteRepository("jdbc:sqlite:$db"))

    Javalin
        .create { config ->
            config.staticFiles.add { staticFiles ->
                staticFiles.hostedPath = "/"
                staticFiles.directory = "./public"
                staticFiles.location = Location.EXTERNAL
            }

            config.requestLogger.http { ctx, ms ->
                // log things here
            }

            config.useVirtualThreads = true

            config.jetty.modifyServletContextHandler {
                it.sessionHandler = fileSessionHandler()
            }
        }
        .also {
            app.register(it)
        }
        .start(7070)
}

fun fileSessionHandler() = SessionHandler().apply {
    sessionCache = DefaultSessionCache(this).apply {
        sessionDataStore = FileSessionDataStore().apply {
            val baseDir = File(System.getProperty("java.io.tmpdir"))
            this.storeDir = File(baseDir, "javalin-session").apply { mkdirs() }
        }
    }
    maxInactiveInterval = 30 * 60
    httpOnly = true
    isSecureRequestOnly = true
    sameSite = HttpCookie.SameSite.STRICT
}