package net.h34t.filemure.controller

import io.javalin.http.Context
import net.h34t.filemure.TemplateModifiers
import net.h34t.filemure.repository.SqliteRepository
import net.h34t.filemure.requireSession

class UploadController(val modifiers: TemplateModifiers, val repository: SqliteRepository) {

    fun upload(ctx: Context) {
        val session = ctx.requireSession()

        val accountid = session.id

        val target = ctx.queryParam("target")

        val files = ctx.uploadedFiles()

        when (target) {
            "document" -> {
                val extIds = files.map {
                    it.contentAndClose { content ->
                        repository.addFileToLimbo(accountid, it.filename(), it.contentType(), it.size(), content).extId
                    }
                }
                ctx.status(200)
                ctx.json(
                    Result(
                        files = files.size,
                        redirect = "/document/new?${extIds.joinToString("&") { "file_id=$it" }}"
                    )
                )
            }

            "limbo" -> {
                files.forEach {
                    it.contentAndClose { content ->
                        repository.addFileToLimbo(accountid, it.filename(), it.contentType(), it.size(), content)
                    }
                }
                ctx.status(200)
                ctx.json(
                    Result(
                        files = files.size,
                        redirect = "/limbo"
                    )
                )
            }
        }
    }

    data class Result(
        val files: Int,
        val redirect: String
    )
}
